package com.ruoyi.doubledefense.service;

import java.util.List;

import com.github.pagehelper.PageInfo;
import com.ruoyi.doubledefense.domain.RiskMeasure;
import com.ruoyi.doubledefense.dto.RiskMeasureDTO;
import com.ruoyi.doubledefense.dto.res.RiskMeasureResultDTO;
import com.ruoyi.doubledefense.dtoGov.RiskMeasureDTOGov;

/**
 * 风险管控措施Service接口
 *
 * @author ruoyi
 * @date 2023-08-03
 */
public interface IRiskMeasureService {

    /**
     * 管控措施
     * 重预防汇聚计算节点
     * @param riskMeasureDTOGov
     * @return
     */
    PageInfo<RiskMeasureDTOGov> govSelectRiskMeasureList(RiskMeasureDTOGov riskMeasureDTOGov);


    /**
     * 查询风险管控措施
     *
     * @param id 风险管控措施主键
     * @return 风险管控措施
     */
    public RiskMeasureResultDTO selectRiskMeasureById(String id);

    /**
     * 查询风险管控措施列表
     *
     * @param riskMeasure 风险管控措施
     * @return 风险管控措施集合
     */
    public List<RiskMeasureResultDTO> selectRiskMeasureList(RiskMeasureDTO riskMeasure);

    /**
     * 新增风险管控措施
     *
     * @param riskMeasure 风险管控措施
     * @return 结果
     */
    public int insertRiskMeasure(RiskMeasureDTO riskMeasure);

    /**
     * 修改风险管控措施
     *
     * @param riskMeasure 风险管控措施
     * @return 结果
     */
    public int updateRiskMeasure(RiskMeasureDTO riskMeasure);

    /**
     * 批量删除风险管控措施
     *
     * @param ids 需要删除的风险管控措施主键集合
     * @return 结果
     */
    public int deleteRiskMeasureByIds(String[] ids);
}

